@@ -30,6 +30,7 @@ if not (
     from parsons.google.google_cloud_storage import GoogleCloudStorage
     from parsons.google.google_bigquery import GoogleBigQuery
     from parsons.phone2action.p2a import Phone2Action
+    from parsons.capitol_canary.capitol_canary import CapitolCanary
     from parsons.mobilize_america.ma import MobilizeAmerica
     from parsons.facebook_ads.facebook_ads import FacebookAds
     from parsons.turbovote.turbovote import TurboVote
@@ -65,6 +66,7 @@ if not (
     from parsons.redash.redash import Redash
     from parsons.bluelink import Bluelink
     from parsons.braintree.braintree import Braintree
+    from parsons.auth0.auth0 import Auth0
 
     __all__ = [
         'VAN',
@@ -82,6 +84,7 @@ if not (
         'GoogleBigQuery',
         'GoogleSheets',
         'Phone2Action',
+        'CapitolCanary',
         'MobilizeAmerica',
         'FacebookAds',
         'Slack',
@@ -120,7 +123,8 @@ if not (
         'Bluelink',
         'Braintree',
         'SMTP',
-        'SendMail'
+        'SendMail',
+        'Auth0'
     ]
 
 # Define the default logging config for Parsons and its submodules. For now the
