@@ -1,6 +1,4 @@
-from parsons.databases.redshift import Redshift
-from parsons.aws import S3
-from parsons.etl.table import Table
+from parsons import Redshift, S3, Table
 from test.utils import assert_matching_tables
 import unittest
 import os
