@@ -1,3 +1,4 @@
+from parsons.etl.table import Table
 import os
 import pytest
 
@@ -11,8 +12,9 @@ def test_something():
     service = SomeService()
     ...
 """
-mark_live_test = pytest.mark.skipif(not os.environ.get('LIVE_TEST'),
-    reason='Skipping because not running live test')
+mark_live_test = pytest.mark.skipif(
+    not os.environ.get('LIVE_TEST'), reason='Skipping because not running live test')
+
 
 # Tests whether a table has the expected structure
 def validate_list(expected_keys, table):
@@ -22,6 +24,7 @@ def validate_list(expected_keys, table):
 
     return True
 
+
 def assert_matching_tables(table1, table2, ignore_headers=False):
     if ignore_headers:
         data1 = table1.data
@@ -30,6 +33,9 @@ def assert_matching_tables(table1, table2, ignore_headers=False):
         data1 = table1
         data2 = table2
 
+    if isinstance(data1, Table) and isinstance(data2, Table):
+        assert data1.num_rows == data2.num_rows
+
     for r1, r2 in zip(data1, data2):
         # Cast both rows to lists, in case they are different types of collections
         assert list(r1) == list(r2)
